# == Class: wordpress
#
# Installation d'un environnement LAMP sur Debian 7 avec Wordpress 4.4.1
#
# === Parameters
#
# Les paramètres $1 $2 de /tmp/mysql sont respectivement le mot de passe root mysql et le mot de passe du compte wordpress mysql données en paramètres dans les userdatas du script de déploiement wordpress.php futurement disponible sur le GitHub Ikoula
#
#
# === Authors
#
# Author JulienQ Ikoula contribATikoula.com
#
# === Copyright
#
# Copyright 2016 JulienQ Ikoula.
#

class lamp::install {

	exec { 'aptgetupdate':
		command => "apt-get update",
		path => "/usr/bin",
		logoutput => on_failure,
	} 

	package { 'apache2':
		ensure => installed,
		require => Exec['aptgetupdate'],
	} 

	package { 'mysql-server':
		ensure => installed,
		require => Package['apache2']
	}
	
	package { 'libapache2-mod-php5':
		ensure => installed,
		require => Package['mysql-server']
	}
	
	package { 'php5-mysql':
		ensure => installed,
		require => Package['libapache2-mod-php5']
	}
	
	file { "/etc/apache2/sites-available/wordpress" :
        source => "/etc/puppet/modules/wordpress/files/etc.apache2.sites-available.wordpress",
		ensure => file,
        owner   => "root",
        group   => "root",
        require => Package['apache2'],
        mode    => 0644
    }
}

class wordpress::install {
	exec { 'wordpress':
		command => 'wget -P /var/www/ https://wordpress.org/wordpress-4.4.1.tar.gz && tar -xvzf /var/www/wordpress-4.4.1.tar.gz -C /var/www/ && chown -R www-data.www-data /var/www/wordpress/ && rm -rf /var/www/wordpress-4.4.1.tar.gz',
		path => [ "/usr/bin", "/bin" ],
		require => Class["lamp::install"],
	}
}
class apache::vhost {
	exec { 'wordpressvhost':
		command => 'a2ensite wordpress && a2dissite default',
		path => [ "/usr/sbin", "/usr/bin" ],
		require => [
				Class["lamp::install"],
				Class["wordpress::install"],
				]
	}
}
class apache::service {
	exec { 'httpreload':
		command => '/etc/init.d/apache2 reload',
		require    => Class["apache::vhost"],
        }
}
class mysql::rootpw {
        exec { 'rootpw':
                command => 'mysqladmin -u root password `awk \'{print $1}\' /tmp/mysql`',
                path => '/usr/bin',
                require => Class["lamp::install"],
                logoutput => on_failure
        }
}
class mysql::wordpressbdd {
        exec { 'wordpressbdd':
                command => 'mysql -u root -p`awk \'{print $1}\' /tmp/mysql` -e "CREATE DATABASE wordpress;"',
                path => '/usr/bin',
                require => [Class["lamp::install"],
                                Class["mysql::rootpw"],
                                ]
        }
}
class mysql::wordpressbdduser {
	 exec { 'wordpressuser':
                command => 'mysql -u root -p`awk \'{print $1}\' /tmp/mysql` -e "CREATE USER \'wordpress\'@\'localhost\' IDENTIFIED BY \'`awk \'{print $2}\' /tmp/mysql`\';"',
                path => [ "/usr/bin", "/bin" ],
                require => [Class["lamp::install"],
                                Class["mysql::rootpw"],
                                ]
        }
}
class mysql::wordpressbddpriv {
	exec { 'wordpresspriv':	
		command => 'mysql -u root -p`awk \'{print $1}\' /tmp/mysql` -e "GRANT ALL PRIVILEGES ON wordpress.* TO \'wordpress\'@\'localhost\';" && rm -f /tmp/mysql',
		path => [ "/usr/bin", "/bin" ], 
		require => Class["mysql::wordpressbdduser"],
		logoutput => on_failure
	}
}
class mysql::service {
        service { "mysql" :
                        ensure     => "running",
                        enable     => "true",
                        hasrestart => "true",
                        hasstatus => "true",
                        require    => [
										Class["lamp::install"],
										Class["mysql::wordpressbdduser"],
									]
        }
}

class wordpress {
        include lamp::install, wordpress::install, apache::vhost, apache::service, mysql::rootpw, mysql::wordpressbdd, mysql::wordpressbdduser, mysql::wordpressbddpriv, mysql::service
}
